@@ -11,11 +11,11 @@
 # under the License.
 
 import json
-import logging
 
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
+from oslo_log import log as logging
 
 from horizon import exceptions
 from horizon import forms
@@ -94,7 +94,7 @@ class DetailView(tabs.TabView):
         try:
             vnffg = tacker_api.tacker.get_vnffg(self.request, vnffg_id)
             vnffg["vnffg"]["mgmt_url"] = json.loads(vnffg["vnffg"]["mgmt_url"]) if \
-                vnffg["vnffg"]["mgmt_url"] else None
+                vnffg["vnffg"].get("mgmt_url") else None
             return vnffg
         except ValueError as e:
             msg = _('Cannot decode json : %s') % e
